@@ -6,6 +6,7 @@ import (
 	"hash"
 	"io"
 	"net/http"
+	"net/url"
 	"os"
 	"os/exec"
 	"path"
@@ -30,6 +31,19 @@ type common struct {
 	client     *http.Client
 }
 
+type httpCustomTransport struct{}
+
+func (ct *httpCustomTransport) RoundTrip(req *http.Request) (*http.Response, error) {
+	if req.Header.Get("Accept") == "" {
+		req.Header.Set("Accept", "*/*")
+	}
+
+	transport := http.DefaultTransport.(*http.Transport).Clone()
+	transport.TLSHandshakeTimeout = 60 * time.Second
+
+	return transport.RoundTrip(req)
+}
+
 func (s *common) init(ctx context.Context, logger *logrus.Logger, definition shared.Definition, rootfsDir string, cacheDir string, sourcesDir string) {
 	s.logger = logger
 	s.definition = definition
@@ -38,10 +52,7 @@ func (s *common) init(ctx context.Context, logger *logrus.Logger, definition sha
 	s.sourcesDir = sourcesDir
 	s.ctx = ctx
 
-	transport := http.DefaultTransport.(*http.Transport).Clone()
-	// Increase TLS handshake timeout for mirrors which need a bit more time.
-	transport.TLSHandshakeTimeout = 60 * time.Second
-
+	transport := &httpCustomTransport{}
 	s.client = &http.Client{
 		Transport: transport,
 	}
@@ -274,3 +285,22 @@ func (s *common) CreateGPGKeyring() (string, error) {
 
 	return filepath.Join(gpgDir, "distrobuilder.gpg"), nil
 }
+
+// Checks GPG key requirements.
+func (s *common) validateGPGRequirements(u *url.URL) (bool, error) {
+	hasKeys := len(s.definition.Source.Keys) != 0
+
+	if hasKeys {
+		// GPG keys provided, always verify regardless of protocol
+		return false, nil
+	} else if u.Scheme != "https" {
+		// Force gpg checks when using http
+		return false, fmt.Errorf("GPG keys are required if downloading from %s", u.Scheme)
+	} else if !s.definition.Source.SkipVerification {
+		// HTTPS without keys: warn but allow
+		s.logger.Warnf("Downloading from %s without GPG keys as no keys were specified", u.Scheme)
+		return true, nil
+	}
+
+	return s.definition.Source.SkipVerification, nil
+}
