@@ -46,7 +46,7 @@ func (s *ubuntu) downloadImage(definition shared.Definition) error {
 				s.definition.Image.Release, s.definition.Image.ArchitectureMapped)
 		} else {
 			// if release is non-numerical, find the latest release
-			s.fname, err = getLatestRelease(baseURL,
+			s.fname, err = s.getLatestRelease(baseURL,
 				s.definition.Image.Release, s.definition.Image.ArchitectureMapped)
 			if err != nil {
 				return fmt.Errorf("Failed to get latest release: %w", err)
@@ -64,15 +64,17 @@ func (s *ubuntu) downloadImage(definition shared.Definition) error {
 		return fmt.Errorf("Failed to parse URL %q: %w", baseURL, err)
 	}
 
+	skip, err := s.validateGPGRequirements(url)
+	if err != nil {
+		return fmt.Errorf("Failed to validate GPG requirements: %w", err)
+	}
+
+	s.definition.Source.SkipVerification = skip
+
 	var fpath string
 
 	checksumFile := ""
-	// Force gpg checks when using http
-	if !s.definition.Source.SkipVerification && url.Scheme != "https" {
-		if len(s.definition.Source.Keys) == 0 {
-			return errors.New("GPG keys are required if downloading from HTTP")
-		}
-
+	if !s.definition.Source.SkipVerification {
 		checksumFile = baseURL + "SHA256SUMS"
 		fpath, err = s.DownloadHash(s.definition.Image, baseURL+"SHA256SUMS.gpg", "", nil)
 		if err != nil {
@@ -125,14 +127,14 @@ func (s ubuntu) unpack(filePath, rootDir string) error {
 	return nil
 }
 
-func getLatestRelease(baseURL, release, arch string) (string, error) {
+func (s ubuntu) getLatestRelease(baseURL, release, arch string) (string, error) {
 	var (
 		resp *http.Response
 		err  error
 	)
 
 	err = shared.Retry(func() error {
-		resp, err = http.Get(baseURL)
+		resp, err = s.client.Get(baseURL)
 		if err != nil {
 			return fmt.Errorf("Failed to GET %q: %w", baseURL, err)
 		}
